@@ -171,7 +171,6 @@ static void	gtk_source_view_get_property		(GObject           *object,
 static void     gtk_source_view_style_set               (GtkWidget         *widget,
 							 GtkStyle          *previous_style);
 
-static void	gtk_source_view_grab_focus		(GtkWidget         *widget);
 
 /* Private functions. */
 static void
@@ -193,7 +192,6 @@ gtk_source_view_class_init (GtkSourceViewClass *klass)
 	
 	widget_class->expose_event = gtk_source_view_expose;
 	widget_class->style_set = gtk_source_view_style_set;
-	widget_class->grab_focus = gtk_source_view_grab_focus;
 
 	textview_class->populate_popup = gtk_source_view_populate_popup;
 	textview_class->move_cursor = gtk_source_view_move_cursor;
@@ -943,12 +941,10 @@ draw_line_markers (GtkSourceView *view,
 		window = gtk_text_view_get_window (GTK_TEXT_VIEW (view),
 						   GTK_TEXT_WINDOW_LEFT);
 
-		gdk_pixbuf_render_to_drawable_alpha (composite,
-						     GDK_DRAWABLE (window),
-						     0, 0, x, y,
-						     width, height,
-						     GDK_PIXBUF_ALPHA_BILEVEL,
-						     127, GDK_RGB_DITHER_NORMAL, 0, 0);
+		gdk_draw_pixbuf (GDK_DRAWABLE (window), NULL, composite,
+				 0, 0, x, y,
+				 width, height,
+				 GDK_RGB_DITHER_NORMAL, 0, 0);
 		g_object_unref (composite);
 	}
 
@@ -1821,6 +1817,7 @@ gtk_source_view_set_margin (GtkSourceView *view, guint margin)
 		return;
 
 	view->priv->margin = margin;
+	view->priv->cached_margin_width = -1;
 
 	gtk_widget_queue_draw (GTK_WIDGET (view));
 
@@ -1884,21 +1881,4 @@ gtk_source_view_style_set (GtkWidget *widget, GtkStyle *previous_style)
 	}
 }
 
-/* This is a workaround for bug #81893.
- * We skip the parent class' grab_focus method in order to avoid the weird 
- * scroll on focus behavior of GtkTextView.
- * The GtkTextView grab_focus method first calls the parent class' 
- * grab_focus method and then scrolls to cursor if disable_scroll_on_focus is
- * FALSE.
- * We will remove this workaround when bug #81893 will be fixed.
- */
-static void
-gtk_source_view_grab_focus (GtkWidget *widget)
-{
-  GtkTextView *text_view;
-
-  text_view = GTK_TEXT_VIEW (widget);
-  
-  GTK_WIDGET_CLASS (g_type_class_peek_parent (parent_class))->grab_focus (widget);
-}
 
